{% extends "arches_urls.htm" %}

{% load static %}
{% load l10n %}
{% load i18n %}

{% block arches_urls %}
{{ block.super }}
<div class="arches-urls"
    api_relatable_resources='(graph_slug, node_alias) => {return "{% url "api-relatable-resources" "----p1" "----p2" %}".replace("----p1", graph_slug).replace("----p2", node_alias)}'
    api_card_x_node_x_widget='(graph_slug, node_alias) => {return "{% url "api-card-x-node-x-widget" "----p1" "----p2" %}".replace("----p1", graph_slug).replace("----p2", node_alias)}'
    api_card_x_node_x_widget_list_from_nodegroup='(graph_slug, nodegroup_alias) => {return "{% url "api-card-x-node-x-widget-list-from-nodegroup" "----p1" "----p2" %}".replace("----p1", graph_slug).replace("----p2", nodegroup_alias)}'
    api_widget_data='(graph_slug, node_alias) => {return "{% url "api-widget-data" "----p1" "----p2" %}".replace("----p1", graph_slug).replace("----p2", node_alias)}'
    api_node_data='(graph_slug, node_alias) => {return "{% url "api-node-data" "----p1" "----p2" %}".replace("----p1", graph_slug).replace("----p2", node_alias)}'
    api_card_data='(graph_slug, nodegroup_alias) => {return "{% url "api-card-data" "----p1" "----p2" %}".replace("----p1", graph_slug).replace("----p2", nodegroup_alias)}'
    api_tile='(graph_slug, nodegroup_alias, tile_id) => { return "{% url "api-tile" "----p1" "----p2" "00000000-0000-0000-0000-000000000000" %}".replace("----p1", graph_slug).replace("----p2", nodegroup_alias).replace("00000000-0000-0000-0000-000000000000", tile_id)}'
    api_tile_list_create='(graph_slug, nodegroup_alias, resource_instance_id) => { return "{% url "api-tile-list-create" "----p1" "----p2" "00000000-0000-0000-0000-000000000000" %}".replace("----p1", graph_slug).replace("----p2", nodegroup_alias).replace("00000000-0000-0000-0000-000000000000", resource_instance_id)}'
></div>
{% endblock arches_urls %}
